"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.prettifyCode = exports.formatCode = void 0;
var _isObject2 = _interopRequireDefault(require("lodash/isObject"));
var _prettier = _interopRequireWildcard(require("prettier/standalone"));
var babel = _interopRequireWildcard(require("prettier/parser-babel"));
var html = _interopRequireWildcard(require("prettier/parser-html"));
var typescript = _interopRequireWildcard(require("prettier/parser-typescript"));
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
// `prettier` is a CJS library, there are known issues with them:
// https://github.com/rollup/rollup/issues/1267#issuecomment-446681320
var prettier = _prettier.default || _prettier;
var prettierConfig = {
  htmlWhitespaceSensitivity: 'ignore',
  printWidth: 100,
  tabWidth: 2,
  semi: false,
  singleQuote: true,
  trailingComma: 'all',
  plugins: {
    babel: babel,
    html: html,
    typescript: typescript
  }
};
var normalizeToString = function normalizeToString(value) {
  if (Array.isArray(value)) return value.join('\n');
  return (0, _isObject2.default)(value) ? JSON.stringify(value, null, 2) : value;
};
var prettifyCode = function prettifyCode(code, parser) {
  var formatted = prettier.format(code, Object.assign({}, prettierConfig, {
    // a narrower print width is more friendly to doc examples
    parser: parser
  }));
  return formatted.replace(/^;</m, '<'); // remove beginning semi in JSX/HTML
};
exports.prettifyCode = prettifyCode;
var formatters = {
  bash: function bash(val) {
    if (val === void 0) {
      val = '';
    }
    return val.replace(/^/g, '$  ');
  },
  json: function json(val) {
    return prettifyCode(val, 'json');
  },
  js: function js(val) {
    if (val === void 0) {
      val = '';
    }
    return prettifyCode(val, 'babel');
  },
  jsx: function jsx(val) {
    if (val === void 0) {
      val = '';
    }
    return prettifyCode(val, 'babel');
  },
  html: function html(val) {
    if (val === void 0) {
      val = '';
    }
    return prettifyCode(val, 'html');
  }
};
var formatCode = function formatCode(code, mode) {
  if (!code) return '';
  var formatter = formatters[mode];
  return formatter(normalizeToString(code))
  // remove eof line break, they are not helpful for snippets
  .replace(/\n$/, '');
};
exports.formatCode = formatCode;
//# sourceMappingURL=formatCode.js.map
