"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.Editor = exports.EDITOR_GUTTER_COLOR = exports.EDITOR_BACKGROUND_COLOR = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));
var _invoke2 = _interopRequireDefault(require("lodash/invoke"));
var _debounce2 = _interopRequireDefault(require("lodash/debounce"));
var _uniqueId2 = _interopRequireDefault(require("lodash/uniqueId"));
var _find2 = _interopRequireDefault(require("lodash/find"));
var _each2 = _interopRequireDefault(require("lodash/each"));
var PropTypes = _interopRequireWildcard(require("prop-types"));
var React = _interopRequireWildcard(require("react"));
var _reactAce = _interopRequireDefault(require("react-ace"));
var ace = _interopRequireWildcard(require("brace"));
require("brace/ext/language_tools");
require("brace/mode/jsx");
require("brace/theme/tomorrow_night_eighties");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
// These are from react-ace and we don't want to depend on brace separately
/* eslint-disable import/no-extraneous-dependencies */
/* eslint-enable import/no-extraneous-dependencies */
var parentComponents = [];

// Set up custom completers by using a ace extension
// https://github.com/thlorenz/brace/issues/19
var languageTools = ace.acequire('ace/ext/language_tools');
var semanticUIReactCompleter = {
  getCompletions: function getCompletions(editor, session, pos, prefix, callback) {
    var completions = [];
    (0, _each2.default)(parentComponents, function (component) {
      var name = component._meta.name;
      // Component
      completions.push({
        caption: name,
        value: name,
        meta: 'Component'
      });

      // Its props (propTypes do not exist in prod, use handledProps added by babel)
      (0, _each2.default)(component.handledProps, function (propName) {
        // don't add duplicate prop completions
        if ((0, _find2.default)(completions, {
          value: propName
        })) return;
        completions.push({
          caption: propName,
          value: propName,
          meta: 'Component Prop'
        });
      });
    });
    callback(null, completions);
  }
};
languageTools.addCompleter(semanticUIReactCompleter);
var EDITOR_BACKGROUND_COLOR = '#2D2D2D';
exports.EDITOR_BACKGROUND_COLOR = EDITOR_BACKGROUND_COLOR;
var EDITOR_GUTTER_COLOR = '#272727';
exports.EDITOR_GUTTER_COLOR = EDITOR_GUTTER_COLOR;
var Editor = /*#__PURE__*/function (_React$PureComponent) {
  (0, _inheritsLoose2.default)(Editor, _React$PureComponent);
  function Editor() {
    var _this;
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    _this = _React$PureComponent.call.apply(_React$PureComponent, [this].concat(args)) || this;
    _this.editorRef = /*#__PURE__*/React.createRef();
    _this.name = "docs-editor-" + (0, _uniqueId2.default)();
    _this.handleChange = (0, _debounce2.default)(function (value, e) {
      (0, _invoke2.default)(_this.props, 'onChange', value, e);
    }, 200);
    _this.setCursorVisibility = function (visible) {
      var cursor = _this.editorRef.current.editor.renderer.$cursorLayer.element;
      cursor.style.display = visible ? '' : 'none';
    };
    return _this;
  }
  var _proto = Editor.prototype;
  _proto.componentDidMount = function componentDidMount() {
    var showCursor = this.props.showCursor;
    this.setCursorVisibility(showCursor);
  };
  _proto.UNSAFE_componentWillReceiveProps = function UNSAFE_componentWillReceiveProps(nextProps) {
    var previousPros = this.props;
    var active = nextProps.active,
      showCursor = nextProps.showCursor;
    if (showCursor !== previousPros.showCursor) {
      this.setCursorVisibility(showCursor);
    }

    // focus editor when editor it becomes active
    if (active !== previousPros.active && active) {
      this.editorRef.current.editor.focus();
    }
  };
  _proto.render = function render() {
    return /*#__PURE__*/React.createElement(_reactAce.default, (0, _extends2.default)({}, this.props, {
      name: this.name,
      onChange: this.handleChange,
      ref: this.editorRef
    }));
  };
  return Editor;
}(React.PureComponent);
exports.Editor = Editor;
Editor.propTypes = {
  value: PropTypes.string.isRequired,
  mode: PropTypes.oneOf(['html', 'json', 'jsx', 'sh']),
  active: PropTypes.bool,
  showCursor: PropTypes.bool
};
Editor.defaultProps = {
  value: '',
  mode: 'jsx',
  theme: 'tomorrow_night_eighties',
  height: '100px',
  width: '100%',
  active: true,
  enableBasicAutocompletion: true,
  enableLiveAutocompletion: true,
  editorProps: {
    $blockScrolling: Infinity
  },
  setOptions: {
    fixedWidthGutter: true,
    showFoldWidgets: false
  },
  showPrintMargin: false,
  tabSize: 2,
  maxLines: Infinity,
  readOnly: false,
  highlightActiveLine: true,
  highlightGutterLine: true,
  showCursor: true
};
//# sourceMappingURL=Editor.js.map
