"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.KnobInspector = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var React = _interopRequireWildcard(require("react"));
var _KnobContexts = require("./KnobContexts");
var _useKnobValues = require("./useKnobValues");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var getKnobControls = function getKnobControls(knobsContext) {
  var _knobsContext$compone = knobsContext.components,
    KnobControl = _knobsContext$compone.KnobControl,
    KnobField = _knobsContext$compone.KnobField,
    KnobLabel = _knobsContext$compone.KnobLabel;
  var controls = {
    Control: KnobControl,
    Field: KnobField,
    Label: KnobLabel
  };
  if (process.env.NODE_ENV !== 'production') {
    Object.keys(controls).forEach(function (name) {
      if (typeof controls[name] === 'undefined') {
        throw new Error("\"" + name + "\" is not defined, please check you mapping");
      }
    });
  }
  return controls;
};
var getKnobComponents = function getKnobComponents(knobsContext) {
  var _knobsContext$compone2 = knobsContext.components,
    KnobBoolean = _knobsContext$compone2.KnobBoolean,
    KnobNumber = _knobsContext$compone2.KnobNumber,
    KnobRange = _knobsContext$compone2.KnobRange,
    KnobSelect = _knobsContext$compone2.KnobSelect,
    KnobString = _knobsContext$compone2.KnobString;
  var components = {
    boolean: KnobBoolean,
    number: KnobNumber,
    range: KnobRange,
    select: KnobSelect,
    string: KnobString
  };
  if (process.env.NODE_ENV !== 'production') {
    Object.keys(components).forEach(function (name) {
      if (typeof components[name] === 'undefined') {
        throw new Error("A component for \"" + name + "\" is not defined, please check you mapping");
      }
    });
  }
  return components;
};
var KnobInspector = function KnobInspector(props) {
  var knobContext = React.useContext(_KnobContexts.KnobContext);
  var _getKnobControls = getKnobControls(knobContext),
    Control = _getKnobControls.Control,
    Field = _getKnobControls.Field,
    Label = _getKnobControls.Label;
  var knobComponents = getKnobComponents(knobContext);
  var knobValues = (0, _useKnobValues.useKnobValues)();
  var children = knobValues.length > 0 ? /*#__PURE__*/React.createElement(React.Fragment, null, knobValues.map(function (knob) {
    var setValue = function setValue(value) {
      return knobContext.setKnobValue(knob.name, value);
    };
    var knobProps = Object.assign({}, knob, {
      setValue: setValue
    });
    return /*#__PURE__*/React.createElement(Field, (0, _extends2.default)({}, knobProps, {
      key: knob.name
    }), /*#__PURE__*/React.createElement(Label, knobProps), /*#__PURE__*/React.createElement(Control, knobProps, /*#__PURE__*/React.createElement(knobComponents[knob.type], knobProps)));
  })) : null;
  return props.children ? props.children(children) : children;
};
exports.KnobInspector = KnobInspector;
//# sourceMappingURL=KnobInspector.js.map
