"use strict";

exports.__esModule = true;
exports.KnobProvider = void 0;
var React = _interopRequireWildcard(require("react"));
var _defaultComponents = require("./defaultComponents");
var _KnobContexts = require("./KnobContexts");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var KnobProvider = function KnobProvider(props) {
  var children = props.children,
    components = props.components;
  var _React$useState = React.useState({}),
    knobs = _React$useState[0],
    setKnobs = _React$useState[1];
  var _React$useState2 = React.useState([]),
    items = _React$useState2[0],
    setItems = _React$useState2[1];
  var registerKnob = function registerKnob(knob) {
    setKnobs(function (prevKnobs) {
      var _Object$assign;
      if (process.env.NODE_ENV !== 'production') {
        if (prevKnobs[knob.name]) {
          throw new Error("Knob with name \"" + knob.name + "\" has been already registered");
        }
      }
      return Object.assign({}, prevKnobs, (_Object$assign = {}, _Object$assign[knob.name] = knob, _Object$assign));
    });
  };
  var setKnobValue = function setKnobValue(knobName, knobValue) {
    setKnobs(function (prevKnob) {
      var _Object$assign2;
      return Object.assign({}, prevKnob, (_Object$assign2 = {}, _Object$assign2[knobName] = Object.assign({}, prevKnob[knobName], {
        value: knobValue
      }), _Object$assign2));
    });
  };
  var unregisterKnob = function unregisterKnob(knobName) {
    setKnobs(function (prevKnobs) {
      var newKnobs = Object.assign({}, prevKnobs);
      delete newKnobs[knobName];
      return newKnobs;
    });
  };
  var appendLog = React.useCallback(function (value) {
    return setItems(function (prevLog) {
      return [].concat(prevLog, [value]);
    });
  }, []);
  var clearLog = React.useCallback(function () {
    return setItems([]);
  }, []);
  var knobValue = React.useMemo(function () {
    return {
      components: Object.assign({}, _defaultComponents.defaultComponents, components),
      knobs: knobs,
      registerKnob: registerKnob,
      setKnobValue: setKnobValue,
      unregisterKnob: unregisterKnob
    };
  }, [knobs, components]);
  var logValue = React.useMemo(function () {
    return {
      appendLog: appendLog,
      clearLog: clearLog
    };
  }, [appendLog, clearLog]);
  return /*#__PURE__*/React.createElement(_KnobContexts.KnobContext.Provider, {
    value: knobValue
  }, /*#__PURE__*/React.createElement(_KnobContexts.LogContextFunctions.Provider, {
    value: logValue
  }, /*#__PURE__*/React.createElement(_KnobContexts.LogContextItems.Provider, {
    value: items
  }, children)));
};
exports.KnobProvider = KnobProvider;
KnobProvider.defaultProps = {
  components: {}
};
//# sourceMappingURL=KnobProvider.js.map
