import _isObject from "lodash/isObject";
import * as _prettier from 'prettier/standalone';
import * as babel from 'prettier/parser-babel';
import * as html from 'prettier/parser-html';
import * as typescript from 'prettier/parser-typescript';
// `prettier` is a CJS library, there are known issues with them:
// https://github.com/rollup/rollup/issues/1267#issuecomment-446681320
var prettier = _prettier.default || _prettier;
var prettierConfig = {
  htmlWhitespaceSensitivity: 'ignore',
  printWidth: 100,
  tabWidth: 2,
  semi: false,
  singleQuote: true,
  trailingComma: 'all',
  plugins: {
    babel: babel,
    html: html,
    typescript: typescript
  }
};
var normalizeToString = function normalizeToString(value) {
  if (Array.isArray(value)) return value.join('\n');
  return _isObject(value) ? JSON.stringify(value, null, 2) : value;
};
export var prettifyCode = function prettifyCode(code, parser) {
  var formatted = prettier.format(code, Object.assign({}, prettierConfig, {
    // a narrower print width is more friendly to doc examples
    parser: parser
  }));
  return formatted.replace(/^;</m, '<'); // remove beginning semi in JSX/HTML
};

var formatters = {
  bash: function bash(val) {
    if (val === void 0) {
      val = '';
    }
    return val.replace(/^/g, '$  ');
  },
  json: function json(val) {
    return prettifyCode(val, 'json');
  },
  js: function js(val) {
    if (val === void 0) {
      val = '';
    }
    return prettifyCode(val, 'babel');
  },
  jsx: function jsx(val) {
    if (val === void 0) {
      val = '';
    }
    return prettifyCode(val, 'babel');
  },
  html: function html(val) {
    if (val === void 0) {
      val = '';
    }
    return prettifyCode(val, 'html');
  }
};
export var formatCode = function formatCode(code, mode) {
  if (!code) return '';
  var formatter = formatters[mode];
  return formatter(normalizeToString(code))
  // remove eof line break, they are not helpful for snippets
  .replace(/\n$/, '');
};
//# sourceMappingURL=formatCode.js.map
