import _extends from "@babel/runtime/helpers/esm/extends";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _invoke from "lodash/invoke";
import _debounce from "lodash/debounce";
import _uniqueId from "lodash/uniqueId";
import _find from "lodash/find";
import _each from "lodash/each";
import * as PropTypes from 'prop-types';
import * as React from 'react';
import AceEditor from 'react-ace';
// These are from react-ace and we don't want to depend on brace separately
/* eslint-disable import/no-extraneous-dependencies */
import * as ace from 'brace';
import 'brace/ext/language_tools';
import 'brace/mode/jsx';
import 'brace/theme/tomorrow_night_eighties';
/* eslint-enable import/no-extraneous-dependencies */

var parentComponents = [];

// Set up custom completers by using a ace extension
// https://github.com/thlorenz/brace/issues/19
var languageTools = ace.acequire('ace/ext/language_tools');
var semanticUIReactCompleter = {
  getCompletions: function getCompletions(editor, session, pos, prefix, callback) {
    var completions = [];
    _each(parentComponents, function (component) {
      var name = component._meta.name;
      // Component
      completions.push({
        caption: name,
        value: name,
        meta: 'Component'
      });

      // Its props (propTypes do not exist in prod, use handledProps added by babel)
      _each(component.handledProps, function (propName) {
        // don't add duplicate prop completions
        if (_find(completions, {
          value: propName
        })) return;
        completions.push({
          caption: propName,
          value: propName,
          meta: 'Component Prop'
        });
      });
    });
    callback(null, completions);
  }
};
languageTools.addCompleter(semanticUIReactCompleter);
export var EDITOR_BACKGROUND_COLOR = '#2D2D2D';
export var EDITOR_GUTTER_COLOR = '#272727';
export var Editor = /*#__PURE__*/function (_React$PureComponent) {
  _inheritsLoose(Editor, _React$PureComponent);
  function Editor() {
    var _this;
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    _this = _React$PureComponent.call.apply(_React$PureComponent, [this].concat(args)) || this;
    _this.editorRef = /*#__PURE__*/React.createRef();
    _this.name = "docs-editor-" + _uniqueId();
    _this.handleChange = _debounce(function (value, e) {
      _invoke(_this.props, 'onChange', value, e);
    }, 200);
    _this.setCursorVisibility = function (visible) {
      var cursor = _this.editorRef.current.editor.renderer.$cursorLayer.element;
      cursor.style.display = visible ? '' : 'none';
    };
    return _this;
  }
  var _proto = Editor.prototype;
  _proto.componentDidMount = function componentDidMount() {
    var showCursor = this.props.showCursor;
    this.setCursorVisibility(showCursor);
  };
  _proto.UNSAFE_componentWillReceiveProps = function UNSAFE_componentWillReceiveProps(nextProps) {
    var previousPros = this.props;
    var active = nextProps.active,
      showCursor = nextProps.showCursor;
    if (showCursor !== previousPros.showCursor) {
      this.setCursorVisibility(showCursor);
    }

    // focus editor when editor it becomes active
    if (active !== previousPros.active && active) {
      this.editorRef.current.editor.focus();
    }
  };
  _proto.render = function render() {
    return /*#__PURE__*/React.createElement(AceEditor, _extends({}, this.props, {
      name: this.name,
      onChange: this.handleChange,
      ref: this.editorRef
    }));
  };
  return Editor;
}(React.PureComponent);
Editor.propTypes = {
  value: PropTypes.string.isRequired,
  mode: PropTypes.oneOf(['html', 'json', 'jsx', 'sh']),
  active: PropTypes.bool,
  showCursor: PropTypes.bool
};
Editor.defaultProps = {
  value: '',
  mode: 'jsx',
  theme: 'tomorrow_night_eighties',
  height: '100px',
  width: '100%',
  active: true,
  enableBasicAutocompletion: true,
  enableLiveAutocompletion: true,
  editorProps: {
    $blockScrolling: Infinity
  },
  setOptions: {
    fixedWidthGutter: true,
    showFoldWidgets: false
  },
  showPrintMargin: false,
  tabSize: 2,
  maxLines: Infinity,
  readOnly: false,
  highlightActiveLine: true,
  highlightGutterLine: true,
  showCursor: true
};
//# sourceMappingURL=Editor.js.map
