import * as React from 'react';
import { defaultComponents } from './defaultComponents';
import { KnobContext, LogContextFunctions, LogContextItems } from './KnobContexts';
export var KnobProvider = /*#__PURE__*/function () {
  var KnobProvider = function KnobProvider(props) {
    var children = props.children,
      components = props.components;
    var _React$useState = React.useState({}),
      knobs = _React$useState[0],
      setKnobs = _React$useState[1];
    var _React$useState2 = React.useState([]),
      items = _React$useState2[0],
      setItems = _React$useState2[1];
    var registerKnob = function registerKnob(knob) {
      setKnobs(function (prevKnobs) {
        var _Object$assign;
        if (process.env.NODE_ENV !== 'production') {
          if (prevKnobs[knob.name]) {
            throw new Error("Knob with name \"" + knob.name + "\" has been already registered");
          }
        }
        return Object.assign({}, prevKnobs, (_Object$assign = {}, _Object$assign[knob.name] = knob, _Object$assign));
      });
    };
    var setKnobValue = function setKnobValue(knobName, knobValue) {
      setKnobs(function (prevKnob) {
        var _Object$assign2;
        return Object.assign({}, prevKnob, (_Object$assign2 = {}, _Object$assign2[knobName] = Object.assign({}, prevKnob[knobName], {
          value: knobValue
        }), _Object$assign2));
      });
    };
    var unregisterKnob = function unregisterKnob(knobName) {
      setKnobs(function (prevKnobs) {
        var newKnobs = Object.assign({}, prevKnobs);
        delete newKnobs[knobName];
        return newKnobs;
      });
    };
    var appendLog = React.useCallback(function (value) {
      return setItems(function (prevLog) {
        return [].concat(prevLog, [value]);
      });
    }, []);
    var clearLog = React.useCallback(function () {
      return setItems([]);
    }, []);
    var knobValue = React.useMemo(function () {
      return {
        components: Object.assign({}, defaultComponents, components),
        knobs: knobs,
        registerKnob: registerKnob,
        setKnobValue: setKnobValue,
        unregisterKnob: unregisterKnob
      };
    }, [knobs, components]);
    var logValue = React.useMemo(function () {
      return {
        appendLog: appendLog,
        clearLog: clearLog
      };
    }, [appendLog, clearLog]);
    return /*#__PURE__*/React.createElement(KnobContext.Provider, {
      value: knobValue
    }, /*#__PURE__*/React.createElement(LogContextFunctions.Provider, {
      value: logValue
    }, /*#__PURE__*/React.createElement(LogContextItems.Provider, {
      value: items
    }, children)));
  };
  KnobProvider.defaultProps = {
    components: {}
  };
  return KnobProvider;
}();
//# sourceMappingURL=KnobProvider.js.map
