import * as React from 'react';
import { parseValue } from './utils/parseRangeValue';
var KnobField = function KnobField(props) {
  return /*#__PURE__*/React.createElement("div", {
    style: {
      borderBottom: '1px solid rgb(234, 234, 234)',
      display: 'flex',
      flexDirection: 'row',
      justifyContent: 'space-between',
      padding: '3px 0'
    }
  }, props.children);
};
var KnobControl = function KnobControl(props) {
  return /*#__PURE__*/React.createElement("span", {
    style: {
      verticalAlign: 'middle',
      width: 150,
      overflow: 'hidden'
    }
  }, props.children);
};
var KnobLabel = function KnobLabel(props) {
  return /*#__PURE__*/React.createElement("label", {
    htmlFor: "knob_" + props.name,
    style: {
      marginRight: 5
    }
  }, props.content || /*#__PURE__*/React.createElement("code", null, props.name));
};
var KnobBoolean = function KnobBoolean(props) {
  return /*#__PURE__*/React.createElement("input", {
    id: "knob_" + props.name,
    checked: props.value,
    onChange: function onChange(e) {
      props.setValue(e.target.checked);
    },
    type: "checkbox",
    value: props.value
  });
};
var KnobNumber = function KnobNumber(props) {
  return /*#__PURE__*/React.createElement("input", {
    id: "knob_" + props.name,
    onChange: function onChange(e) {
      var newValue = parseInt(e.target.value, 10);
      var min = parseInt(props.min, 10);
      var max = parseInt(props.max, 10);
      if (newValue < min) {
        newValue = min;
      } else if (newValue > max) {
        newValue = max;
      }
      props.setValue(newValue || props.min);
    },
    min: props.min,
    max: props.max,
    step: props.step,
    type: "number",
    value: props.value
  });
};
var KnobSelect = function KnobSelect(props) {
  return /*#__PURE__*/React.createElement("select", {
    id: "knob_" + props.name,
    onChange: function onChange(e) {
      props.setValue(e.target.value);
    },
    value: props.value,
    style: {
      width: '100%'
    }
  }, props.values && props.values.map(function (option) {
    return /*#__PURE__*/React.createElement("option", {
      key: option,
      value: option
    }, option);
  }));
};
var KnobRange = function KnobRange(props) {
  return /*#__PURE__*/React.createElement("input", {
    id: "knob_" + props.name,
    type: "range",
    min: props.min,
    max: props.max,
    step: props.step,
    value: parseValue(props.value),
    onChange: function onChange(e) {
      props.setValue("" + e.target.value + props.unit);
    },
    style: {
      width: '100%'
    }
  });
};
var KnobString = function KnobString(props) {
  return /*#__PURE__*/React.createElement("input", {
    id: "knob_" + props.name,
    onChange: function onChange(e) {
      props.setValue(e.target.value);
    },
    value: props.value,
    style: {
      width: '100%'
    }
  });
};
var LogInspector = function LogInspector(props) {
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    style: {
      display: 'flex',
      padding: 5
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      flexGrow: 1
    }
  }, "Event log", ' ', /*#__PURE__*/React.createElement("span", {
    style: {
      padding: 3,
      background: '#ccc',
      borderRadius: '4rem',
      minWidth: '1.75rem',
      minHeight: '1.75rem',
      display: 'inline-block',
      textAlign: 'center'
    }
  }, props.items.length)), /*#__PURE__*/React.createElement("button", {
    onClick: props.clearLog,
    style: {
      fontSize: '0.9rem'
    }
  }, "Clear")), props.items.length > 0 && /*#__PURE__*/React.createElement("div", {
    style: {
      background: 'rgba(0, 0, 0, 0.04)',
      display: 'flex',
      flexDirection: 'column',
      fontFamily: 'monospace',
      fontSize: '0.9rem',
      padding: 5
    }
  }, props.items.map(function (line, index) {
    return /*#__PURE__*/React.createElement("div", {
      key: index
    }, line);
  })));
};
export var defaultComponents = {
  KnobControl: KnobControl,
  KnobField: KnobField,
  KnobLabel: KnobLabel,
  KnobBoolean: KnobBoolean,
  KnobNumber: KnobNumber,
  KnobRange: KnobRange,
  KnobSelect: KnobSelect,
  KnobString: KnobString,
  LogInspector: LogInspector
};
//# sourceMappingURL=defaultComponents.js.map
